@@ -12,7 +12,7 @@ from matplotlib.patches import Circle
 import glob
 import scipy.constants as sc
 import cv2
-
+import os
 
 # --------------------------------------------------------------------------------
 # main
@@ -25,33 +25,12 @@ def main():
 # functions
 # --------------------------------------------------------------------------------
 
-class alfahor():
+class alfahor(object):
 
     """
-    ``alfahor`` is an instance that reads a spectral cube (FITS file format) and handles
+    ``alfahor`` is a class that reads a spectral cube (FITS file format) and handles
     channel masks that can be created interactively to obtain the vertical structure of
     a certain molecule.
-
-    Args:
-        fits_file (str): Path to the fits file.
-        pa (float): position angle of source [degrees]. Can be positive or negative, sign
-        must be defined such that the lower side of the emission is towards the south once
-        the system has been rotated.
-        inc (float): inclination angle of source [degrees].
-        dist (float): distance of source [parsec].
-        vsys (float): system velocity [km/s].
-        folder (string): folder where masks are or will be saved.
-
-        ang_limit (Optional[float]): If specified, clip data to a square field of view with
-        sides given by 'ang_limit' [arcsec]. Default is 5.0.
-        use_folder_masks (Optional[bool]): If masks have already been saved for this source
-        in 'folder' set to ''True''. This will ensure the data size is equal to the previous
-        mask size. Default assumes no previous masks exist ''False''.
-        dx (Optional[float]): in case the data is not centered, 'dx' allows to shift the data
-        in the horizontal axis [pixel]. Default is 0, data is assumed to be centered.
-        dy (Optional[float]): in case the data is not centered, 'dx' allows to shift the data
-        in the vertical axis [pixel]. Default is 0, data is assumed to be centered.
-
     """
 
     cid = None
@@ -63,6 +42,38 @@ class alfahor():
     lines_near = []
 
     def __init__(self, fits_file, pa, inc, dist, vsys, folder, ang_limit=5.0, use_folder_masks=False, dx=0, dy=0):
+        """
+        Initialise alfahor
+
+        Parameters
+        ----------
+        fits_file (str) : Path to the fits file.
+
+        pa (float) : position angle of source [degrees]. Can be positive or negative, sign
+        must be defined such that the lower side of the emission is towards the south once
+        the system has been rotated.
+
+        inc (float) : inclination angle of source [degrees].
+
+        dist (float) : distance of source [parsec].
+
+        vsys (float) : system velocity [km/s].
+
+        folder (string) : folder where masks are or will be saved.
+
+        ang_limit (Optional[float]) : If specified, clip data to a square field of view with
+        sides given by 'ang_limit' [arcsec]. Default is 5.0.
+
+        use_folder_masks (Optional[bool]) : If masks have already been saved for this source
+        in 'folder' set to ''True''. This will ensure the data size is equal to the previous
+        mask size. Default assumes no previous masks exist ''False''.
+
+        dx (Optional[float]) : in case the data is not centered, 'dx' allows to shift the data
+        in the horizontal axis [pixel]. Default is 0, data is assumed to be centered.
+
+        dy (Optional[float]) : in case the data is not centered, 'dx' allows to shift the data
+        in the vertical axis [pixel]. Default is 0, data is assumed to be centered.
+        """
 
         open_fits = fits.open(fits_file)
         self.data_all = np.squeeze(np.squeeze(open_fits[0].data))
@@ -71,11 +82,21 @@ class alfahor():
         self.pix_scale = np.round(abs(open_fits[0].header['CDELT1'])*3600,6)
         self.bmaj = np.radians(open_fits[0].header['bmaj']) * 206265
         self.bmin = np.radians(open_fits[0].header['bmin']) * 206265
-        self.freq_0 = open_fits[0].header['RESTFRQ']
-        self.freq_init = open_fits[0].header['CRVAL3']
-        self.freq_delta = open_fits[0].header['CDELT3']
+        self.unit_axis3 = open_fits[0].header['CUNIT3']
+        if self.unit_axis3 == 'Hz':
+            self.freq_0 = open_fits[0].header['RESTFRQ']
+            self.freq_init = open_fits[0].header['CRVAL3']
+            self.freq_delta = open_fits[0].header['CDELT3']
+        if self.unit_axis3 == 'm/s':
 
-        self.vsys = vsys
+            self.vel_init = open_fits[0].header['CRVAL3']
+            self.vel_delta = open_fits[0].header['CDELT3']
+
+        self.vsys = vsys*1e3
+
+        if not os.path.isdir(folder):
+            print ('Creating folder %s'%folder)
+            os.system('mkdir %s'%folder)
 
         if not use_folder_masks:
             self.limits = ang_limit/self.pix_scale
@@ -122,7 +143,7 @@ class alfahor():
         self.vert_struct_h = None
 
         self.im_power = 1
-        pass
+
 
     def plot_interactive(self):
 
@@ -145,13 +166,22 @@ class alfahor():
 
         self.ax_power_im_slider = plt.axes([0.25, 0.1, 0.65, 0.03])
 
+
         self.chan_slider = Slider(self.ax_chan_slider, "Channel", 0, len(self.data_all)+1,
-                                    valinit=self.chan, valstep=np.arange(0, len(self.data_all)+1),
-                                    color="green", initcolor='none')
+                                  valinit=self.chan,
+                                  valstep=1,
+                                  #valstep=np.arange(0, len(self.data_all)+1),
+                                  color="green",
+                                  #initcolor='none' #--> Available in mpl>v3.5 only
+        )
 
         self.power_im_slider = Slider(self.ax_power_im_slider, "Scale Image", 0, 2,
-                                    valinit=self.im_power, valstep=np.linspace(0,2,21),
-                                    color="blue", initcolor='none')
+                                      valinit=self.im_power,
+                                      valstep=0.1,
+                                      #valstep=np.linspace(0,2,21),
+                                      color="blue",
+                                      #initcolor='none'
+        )
 
 
         self.chan_slider.on_changed(self.update_chan_slider)
@@ -248,6 +278,7 @@ class alfahor():
         if self.side == 'near':
             self.mask_near = mask_chan
             np.save(self.folder + '/mask_near_chan_' + str(self.chan), np.array([self.mask_near]+ [self.chan], dtype=object))
+
         if self.side == 'far':
             self.mask_far = mask_chan
             np.save(self.folder + '/mask_far_chan_' + str(self.chan), np.array([self.mask_far]+ [self.chan], dtype=object))
@@ -408,11 +439,16 @@ class alfahor():
         Returns:
           vchan (float): channel velocity.
         """
+        if self.unit_axis3 == 'Hz':
+            vchan = sc.c*(1 - ((self.freq_init + chan*self.freq_delta)/self.freq_0))
 
-        vchan = sc.c*(1 - ((self.freq_init + chan*self.freq_delta)/self.freq_0))/1e3
+            v_init = sc.c*(1 - ((self.freq_init + self.freq_delta)/self.freq_0))
+            v_end = sc.c*(1 - ((self.freq_init + len(self.data_all)*self.freq_delta)/self.freq_0))
 
-        v_init = sc.c*(1 - ((self.freq_init + self.freq_delta)/self.freq_0))/1e3
-        v_end = sc.c*(1 - ((self.freq_init + len(self.data_all)*self.freq_delta)/self.freq_0))/1e3
+        if self.unit_axis3 == 'm/s':
+            vchan = (self.vel_init + chan*self.vel_delta)
+            v_init = self.vel_init
+            v_end = (self.vel_init + len(self.data_all)*self.vel_delta )
 
         if v_init>v_end:
             return -(vchan - self.vsys)
@@ -430,10 +466,13 @@ class alfahor():
           ctrl_chan (float): channel number of emission closest to the systemic velocity.
           vmax (float): maximum emission value in ctrl_chan [Jy/beam]
         """
+        if self.unit_axis3 == 'Hz':
+            ctrl_chan = int(np.round( (self.freq_0 * (1- self.vsys/sc.c) - self.freq_init) / self.freq_delta))
+
+        if self.unit_axis3 == 'm/s':
+            ctrl_chan = int(np.round((self.vsys - self.vel_init)/self.vel_delta))
 
-        ctrl_chan = int(np.round( (self.freq_0 * (1- self.vsys*1e3/sc.c) - self.freq_init) / self.freq_delta))
         vmax = max(np.concatenate(self.data_all[ctrl_chan]))
-
         return ctrl_chan, vmax
 
     def tracing_maxima(self):
